summaryrefslogtreecommitdiff
path: root/fml/lib
diff options
context:
space:
mode:
authorfukachan <fukachan>2003-12-31 03:49:15 +0000
committerfukachan <fukachan>2003-12-31 03:49:15 +0000
commited1d2894755d8ba93c35a58f28ad7c8a17b9b7d5 (patch)
tree147f53bdc2aec53358c3402da5cd8b2394511259 /fml/lib
parent602d86bd3f907861fa467e5f4dc09b8a6f5342ad (diff)
downloadfml8-ed1d2894755d8ba93c35a58f28ad7c8a17b9b7d5.tar.gz
fml8-ed1d2894755d8ba93c35a58f28ad7c8a17b9b7d5.tar.bz2
fml8-ed1d2894755d8ba93c35a58f28ad7c8a17b9b7d5.zip
update comments
Diffstat (limited to 'fml/lib')
-rw-r--r--fml/lib/FML/Cache/Journal.pm10
-rw-r--r--fml/lib/FML/Command/Admin/addpriv.pm6
-rw-r--r--fml/lib/FML/Command/Admin/adminadd.pm6
-rw-r--r--fml/lib/FML/Command/Admin/byeadmin.pm6
-rw-r--r--fml/lib/FML/Command/Admin/byepriv.pm6
-rw-r--r--fml/lib/FML/Command/Admin/deladmin.pm20
-rw-r--r--fml/lib/FML/Command/Admin/delmoderator.pm26
-rw-r--r--fml/lib/FML/Command/Admin/dir.pm3
-rw-r--r--fml/lib/FML/Command/Admin/off.pm18
-rw-r--r--fml/lib/FML/Command/Admin/on.pm16
-rw-r--r--fml/lib/FML/Command/Admin/pass.pm7
-rw-r--r--fml/lib/FML/Command/Admin/password.pm4
-rw-r--r--fml/lib/FML/Command/Admin/resign.pm4
-rw-r--r--fml/lib/FML/Command/Admin/unsubscribe.pm22
-rw-r--r--fml/lib/FML/Command/User/add.pm5
-rw-r--r--fml/lib/FML/Command/User/get.pm6
-rw-r--r--fml/lib/FML/Command/User/info.pm3
-rw-r--r--fml/lib/FML/Command/User/mget.pm5
-rw-r--r--fml/lib/FML/Command/User/off.pm6
-rw-r--r--fml/lib/FML/Command/User/on.pm3
-rw-r--r--fml/lib/FML/Command/User/remove.pm5
-rw-r--r--fml/lib/FML/Command/User/resign.pm5
-rw-r--r--fml/lib/FML/Command/User/send.pm9
-rw-r--r--fml/lib/FML/Command/User/signoff.pm3
24 files changed, 125 insertions, 79 deletions
diff --git a/fml/lib/FML/Cache/Journal.pm b/fml/lib/FML/Cache/Journal.pm
index 77516be4..73b18990 100644
--- a/fml/lib/FML/Cache/Journal.pm
+++ b/fml/lib/FML/Cache/Journal.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Journal.pm,v 1.2 2003/12/06 04:48:18 fukachan Exp $
+# $FML: Journal.pm,v 1.3 2003/12/30 03:47:54 fukachan Exp $
#
package FML::Cache::Journal;
@@ -14,7 +14,7 @@ use Carp;
=head1 NAME
-FML::Cache::Journal - inteface into Tie::JournaledDir
+FML::Cache::Journal - interface into Tie::JournaledDir
=head1 SYNOPSIS
@@ -24,9 +24,9 @@ FML::Cache::Journal - inteface into Tie::JournaledDir
=head2 new($curproc)
-=head2 open_db()
+=head2 open($cache_dir, $class)
-=head2 close_db()
+=head2 close()
=cut
@@ -58,7 +58,7 @@ sub open
my (%db) = ();
use File::Spec;
- my $dir = File::Spec->catfile($cache_dir, $class);
+ my $dir = File::Spec->catfile($cache_dir, $class);
unless (-d $dir) {
$curproc->mkdir($dir, $mode);
}
diff --git a/fml/lib/FML/Command/Admin/delmoderator.pm b/fml/lib/FML/Command/Admin/delmoderator.pm
index 5e2855dd..4d6be734 100644
--- a/fml/lib/FML/Command/Admin/delmoderator.pm
+++ b/fml/lib/FML/Command/Admin/delmoderator.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: delmoderator.pm,v 1.11 2003/09/27 03:00:17 fukachan Exp $
+# $FML: delmoderator.pm,v 1.12 2003/11/23 03:54:45 fukachan Exp $
#
package FML::Command::Admin::delmoderator;
@@ -59,22 +59,28 @@ sub need_lock { 1;}
sub lock_channel { return 'command_serialize';}
-# Descriptions: remove the specified moderator
+# Descriptions: remove the specified moderator.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: update $member_map $recipient_map
# Return Value: none
sub process
{
my ($self, $curproc, $command_args) = @_;
- my $config = $curproc->config();
-
- # target maps
+ my $config = $curproc->config();
+ my $options = $command_args->{ options };
+ my $address = $command_args->{ command_data } || $options->[ 0 ];
+
+ # XXX We should always add/rewrite only $primary_*_map maps via
+ # XXX command mail, CUI and GUI.
+ # XXX Rewriting of maps not $primary_*_map is
+ # XXX 1) may be not writable.
+ # XXX 2) ambigous and dangerous
+ # XXX since the map is under controlled by other module.
+ # XXX for example, one of member_maps is under admin_member_maps.
my $member_map = $config->{ 'primary_moderator_member_map' };
my $recipient_map = $config->{ 'primary_moderator_recipient_map' };
- my $options = $command_args->{ options };
- my $address = $command_args->{ command_data } || $options->[ 0 ];
- # fundamental check
+ # fundamental sanity check
croak("address not undefined") unless defined $address;
croak("address not specified") unless $address;
croak("member_map not undefined") unless defined $member_map;
@@ -82,7 +88,7 @@ sub process
croak("recipient_map not undefined") unless defined $recipient_map;
croak("recipient_map not specified") unless $recipient_map;
- # $uc_args = FML::User::Control specific parameters
+ # $uc_args = FML::User::Control specific parameters
my $maplist = [ $member_map, $recipient_map ];
my $uc_args = {
address => $address,
@@ -101,7 +107,7 @@ sub process
}
-# Descriptions: show cgi menu to remove the moderator
+# Descriptions: show cgi menu to remove the moderator.
# Arguments: OBJ($self)
# OBJ($curproc) HASH_REF($args) HASH_REF($command_args)
# Side Effects: update $member_map $recipient_map
diff --git a/fml/lib/FML/Command/Admin/dir.pm b/fml/lib/FML/Command/Admin/dir.pm
index 79694d00..20c388fa 100644
--- a/fml/lib/FML/Command/Admin/dir.pm
+++ b/fml/lib/FML/Command/Admin/dir.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: dir.pm,v 1.12 2003/08/23 04:35:30 fukachan Exp $
+# $FML: dir.pm,v 1.13 2003/08/29 15:33:58 fukachan Exp $
#
package FML::Command::Admin::dir;
@@ -83,6 +83,7 @@ sub process
# XXX-TODO: $du_args->{ options } is used later for what ?
# $du_args->{ options } = \@argv;
+ # XXX-TODO: $dir = new FML::Command::DirUtils $dir_string; $dir->list(). ?
use FML::Command::DirUtils;
my $obj = new FML::Command::DirUtils;
$obj->dir($curproc, $command_args, $du_args);
diff --git a/fml/lib/FML/Command/Admin/off.pm b/fml/lib/FML/Command/Admin/off.pm
index 8471e332..0469e06f 100644
--- a/fml/lib/FML/Command/Admin/off.pm
+++ b/fml/lib/FML/Command/Admin/off.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: off.pm,v 1.12 2003/09/27 03:00:16 fukachan Exp $
+# $FML: off.pm,v 1.13 2003/11/23 03:54:45 fukachan Exp $
#
package FML::Command::Admin::off;
@@ -66,12 +66,20 @@ sub lock_channel { return 'command_serialize';}
sub process
{
my ($self, $curproc, $command_args) = @_;
- my $config = $curproc->config();
+ my $config = $curproc->config();
+ my $options = $command_args->{ options };
+ my $address = $command_args->{ command_data } || $options->[ 0 ];
+
+ # XXX We should always add/rewrite only $primary_*_map maps via
+ # XXX command mail, CUI and GUI.
+ # XXX Rewriting of maps not $primary_*_map is
+ # XXX 1) may be not writable.
+ # XXX 2) ambigous and dangerous
+ # XXX since the map is under controlled by other module.
+ # XXX for example, one of member_maps is under admin_member_maps.
my $recipient_map = $config->{ 'primary_recipient_map' };
- my $options = $command_args->{ options };
- my $address = $command_args->{ command_data } || $options->[ 0 ];
- # fundamental check
+ # fundamental sanity check
croak("address not defined") unless defined $address;
croak("address not specified") unless $address;
croak("\$recipient_map not specified") unless $recipient_map;
diff --git a/fml/lib/FML/Command/Admin/on.pm b/fml/lib/FML/Command/Admin/on.pm
index e119085a..e7060bff 100644
--- a/fml/lib/FML/Command/Admin/on.pm
+++ b/fml/lib/FML/Command/Admin/on.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: on.pm,v 1.12 2003/09/27 03:00:17 fukachan Exp $
+# $FML: on.pm,v 1.13 2003/11/23 03:54:46 fukachan Exp $
#
package FML::Command::Admin::on;
@@ -66,10 +66,18 @@ sub lock_channel { return 'command_serialize';}
sub process
{
my ($self, $curproc, $command_args) = @_;
- my $config = $curproc->config();
+ my $config = $curproc->config();
+ my $options = $command_args->{ options };
+ my $address = $command_args->{ command_data } || $options->[ 0 ];
+
+ # XXX We should always add/rewrite only $primary_*_map maps via
+ # XXX command mail, CUI and GUI.
+ # XXX Rewriting of maps not $primary_*_map is
+ # XXX 1) may be not writable.
+ # XXX 2) ambigous and dangerous
+ # XXX since the map is under controlled by other module.
+ # XXX for example, one of member_maps is under admin_member_maps.
my $recipient_map = $config->{ primary_recipient_map };
- my $options = $command_args->{ options };
- my $address = $command_args->{ command_data } || $options->[ 0 ];
# fundamental check
croak("address not defined") unless defined $address;
diff --git a/fml/lib/FML/Command/Admin/password.pm b/fml/lib/FML/Command/Admin/password.pm
index 36338dcb..2866f492 100644
--- a/fml/lib/FML/Command/Admin/password.pm
+++ b/fml/lib/FML/Command/Admin/password.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: password.pm,v 1.9 2003/03/18 10:42:43 fukachan Exp $
+# $FML: password.pm,v 1.10 2003/08/23 04:35:31 fukachan Exp $
#
package FML::Command::Admin::password;
@@ -15,7 +15,7 @@ use Carp;
=head1 NAME
-FML::Command::Admin::password - authenticate the admin password
+FML::Command::Admin::password - authenticate the remote admin password
=head1 SYNOPSIS
diff --git a/fml/lib/FML/Command/Admin/resign.pm b/fml/lib/FML/Command/Admin/resign.pm
index 9d1507ed..488e21a1 100644
--- a/fml/lib/FML/Command/Admin/resign.pm
+++ b/fml/lib/FML/Command/Admin/resign.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: resign.pm,v 1.8 2002/09/11 23:18:08 fukachan Exp $
+# $FML: resign.pm,v 1.9 2002/09/22 14:56:46 fukachan Exp $
#
package FML::Command::Admin::resign;
@@ -17,7 +17,7 @@ use FML::Command::Admin::unsubscribe;
@ISA = qw(FML::Command::Admin::unsubscribe);
-# Descriptions: unsubscribe user
+# Descriptions: remove the specified user.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to unsubscribe module
# Return Value: none
diff --git a/fml/lib/FML/Command/Admin/unsubscribe.pm b/fml/lib/FML/Command/Admin/unsubscribe.pm
index cfe910c2..ae0853f3 100644
--- a/fml/lib/FML/Command/Admin/unsubscribe.pm
+++ b/fml/lib/FML/Command/Admin/unsubscribe.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: unsubscribe.pm,v 1.26 2003/09/27 03:00:15 fukachan Exp $
+# $FML: unsubscribe.pm,v 1.27 2003/11/23 03:54:46 fukachan Exp $
#
package FML::Command::Admin::unsubscribe;
@@ -15,7 +15,7 @@ use Carp;
=head1 NAME
-FML::Command::Admin::unsubscribe - remove the specified member
+FML::Command::Admin::unsubscribe - remove the specified user
=head1 SYNOPSIS
@@ -68,19 +68,27 @@ sub lock_channel { return 'command_serialize';}
sub process
{
my ($self, $curproc, $command_args) = @_;
- my $config = $curproc->config();
+ my $config = $curproc->config();
+ my $options = $command_args->{ options };
+ my $address = $command_args->{ command_data } || $options->[ 0 ];
+
+ # XXX We should always add/rewrite only $primary_*_map maps via
+ # XXX command mail, CUI and GUI.
+ # XXX Rewriting of maps not $primary_*_map is
+ # XXX 1) may be not writable.
+ # XXX 2) ambigous and dangerous
+ # XXX since the map is under controlled by other module.
+ # XXX for example, one of member_maps is under admin_member_maps.
my $member_map = $config->{ 'primary_member_map' };
my $recipient_map = $config->{ 'primary_recipient_map' };
- my $options = $command_args->{ options };
- my $address = $command_args->{ command_data } || $options->[ 0 ];
- # fundamental check
+ # fundamental sanity check
croak("address not defined") unless defined $address;
croak("address not specified") unless $address;
croak("member_map not specified") unless $member_map;
croak("recipient_map not specified") unless $recipient_map;
- # FML::User::Control specific parameters
+ # $uc_args = FML::User::Control specific parameters
my $maplist = [ $member_map, $recipient_map ];
my $uc_args = {
address => $address,
diff --git a/fml/lib/FML/Command/User/add.pm b/fml/lib/FML/Command/User/add.pm
index d46fadcb..98c9e631 100644
--- a/fml/lib/FML/Command/User/add.pm
+++ b/fml/lib/FML/Command/User/add.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: add.pm,v 1.9 2002/09/22 14:56:47 fukachan Exp $
+# $FML: add.pm,v 1.10 2002/12/15 13:46:30 fukachan Exp $
#
package FML::Command::User::add;
@@ -38,7 +38,8 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-forward request to C<FML::Command::User::subscribe> module.
+Alias of C<subscribe>.
+This request is forwarded to C<FML::Command::User::subscribe> module.
=head1 CODING STYLE
diff --git a/fml/lib/FML/Command/User/get.pm b/fml/lib/FML/Command/User/get.pm
index 1b4f8c12..f66a3e71 100644
--- a/fml/lib/FML/Command/User/get.pm
+++ b/fml/lib/FML/Command/User/get.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: get.pm,v 1.18 2003/08/23 07:24:44 fukachan Exp $
+# $FML: get.pm,v 1.19 2003/10/15 01:03:30 fukachan Exp $
#
package FML::Command::User::get;
@@ -18,7 +18,7 @@ use FML::Log qw(Log LogWarn LogError);
=head1 NAME
-FML::Command::User::get - send back articles
+FML::Command::User::get - send back article(s)
=head1 SYNOPSIS
@@ -26,7 +26,7 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-send back articles.
+send back article(s).
=head1 METHODS
diff --git a/fml/lib/FML/Command/User/info.pm b/fml/lib/FML/Command/User/info.pm
index 1cf44bd1..b4391822 100644
--- a/fml/lib/FML/Command/User/info.pm
+++ b/fml/lib/FML/Command/User/info.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: info.pm,v 1.7 2002/09/22 14:56:47 fukachan Exp $
+# $FML: info.pm,v 1.8 2002/12/15 13:46:30 fukachan Exp $
#
package FML::Command::User::info;
@@ -39,6 +39,7 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
an alias of "guide" module.
+send back guide file.
=head1 CODING STYLE
diff --git a/fml/lib/FML/Command/User/mget.pm b/fml/lib/FML/Command/User/mget.pm
index 44101aec..04a790c7 100644
--- a/fml/lib/FML/Command/User/mget.pm
+++ b/fml/lib/FML/Command/User/mget.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: mget.pm,v 1.11 2002/09/22 14:56:47 fukachan Exp $
+# $FML: mget.pm,v 1.12 2002/12/15 13:46:30 fukachan Exp $
#
package FML::Command::User::mget;
@@ -38,7 +38,8 @@ forwarded C<FML::Command::User::get>.
=head1 DESCRIPTION
-an alias of C<FML::Command::User::get>.
+This module sends back article(s).
+An alias of C<FML::Command::User::get>.
=head1 CODING STYLE
diff --git a/fml/lib/FML/Command/User/off.pm b/fml/lib/FML/Command/User/off.pm
index 01c342a1..bc12ab4d 100644
--- a/fml/lib/FML/Command/User/off.pm
+++ b/fml/lib/FML/Command/User/off.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: off.pm,v 1.12 2003/11/22 05:41:51 fukachan Exp $
+# $FML: off.pm,v 1.13 2003/12/30 03:07:54 fukachan Exp $
#
package FML::Command::User::off;
@@ -24,8 +24,8 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-change delivery mode from real time to digest
-after confirmation succeeds.
+change delivery mode from real time to digest after confirmation
+succeeds.
=head1 METHODS
diff --git a/fml/lib/FML/Command/User/on.pm b/fml/lib/FML/Command/User/on.pm
index 57c54349..75ee1fe7 100644
--- a/fml/lib/FML/Command/User/on.pm
+++ b/fml/lib/FML/Command/User/on.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: on.pm,v 1.12 2003/11/22 05:41:51 fukachan Exp $
+# $FML: on.pm,v 1.13 2003/12/30 03:07:54 fukachan Exp $
#
package FML::Command::User::on;
@@ -99,6 +99,7 @@ sub process
return;
}
+ # XXX-TODO: this message is correct ?
# if already recipient, on request is wrong.
if ($cred->is_recipient($address)) {
$curproc->reply_message_nl('error.already_recipient',
diff --git a/fml/lib/FML/Command/User/remove.pm b/fml/lib/FML/Command/User/remove.pm
index ccd14ae5..1f941616 100644
--- a/fml/lib/FML/Command/User/remove.pm
+++ b/fml/lib/FML/Command/User/remove.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: remove.pm,v 1.10 2002/09/22 14:56:48 fukachan Exp $
+# $FML: remove.pm,v 1.11 2002/12/15 13:46:30 fukachan Exp $
#
package FML::Command::User::remove;
@@ -38,7 +38,8 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-alias of C<FML::Command::User::unsubscribe>.
+Alias of C<FML::Command::User::unsubscribe>.
+The unsubscribe request is forwarded to C<FML::Command::User::unsubscribe>.
=head1 CODING STYLE
diff --git a/fml/lib/FML/Command/User/resign.pm b/fml/lib/FML/Command/User/resign.pm
index 09321aea..48795f8d 100644
--- a/fml/lib/FML/Command/User/resign.pm
+++ b/fml/lib/FML/Command/User/resign.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: resign.pm,v 1.10 2002/09/22 14:56:48 fukachan Exp $
+# $FML: resign.pm,v 1.11 2002/12/15 13:46:30 fukachan Exp $
#
package FML::Command::User::resign;
@@ -37,7 +37,8 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-all requests are forwarded to C<FML::Command::User::unsubscribe>.
+Alias of C<FML::Command::User::unsubscribe>.
+The unsubscribe request is forwarded to C<FML::Command::User::unsubscribe>.
=head1 CODING STYLE
diff --git a/fml/lib/FML/Command/User/signoff.pm b/fml/lib/FML/Command/User/signoff.pm
index dba37bad..73a67fcc 100644
--- a/fml/lib/FML/Command/User/signoff.pm
+++ b/fml/lib/FML/Command/User/signoff.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: signoff.pm,v 1.11 2002/09/22 14:56:48 fukachan Exp $
+# $FML: signoff.pm,v 1.12 2002/12/15 13:46:31 fukachan Exp $
#
package FML::Command::User::signoff;
@@ -39,6 +39,7 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
an alias of C<FML::Command::User::unsubscribe>.
+This request is forwarded to C<FML::Command::User::unsubscribe> module.
=head1 CODING STYLE
diff --git a/fml/lib/FML/Command/Admin/addpriv.pm b/fml/lib/FML/Command/Admin/addpriv.pm
index 568ade89..f02784ef 100644
--- a/fml/lib/FML/Command/Admin/addpriv.pm
+++ b/fml/lib/FML/Command/Admin/addpriv.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: addpriv.pm,v 1.3 2002/09/11 23:18:06 fukachan Exp $
+# $FML: addpriv.pm,v 1.4 2002/09/22 14:56:44 fukachan Exp $
#
package FML::Command::Admin::addpriv;
@@ -17,7 +17,7 @@ use FML::Command::Admin::addadmin;
@ISA = qw(FML::Command::Admin::addadmin);
# Descriptions: add a new admin user
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to addadmin module
# Return Value: none
@@ -29,7 +29,7 @@ sub process
=head1 NAME
-FML::Command::Admin::add - add a new administrator
+FML::Command::Admin::add - add a new remote administrator
=head1 SYNOPSIS
@@ -17,7 +17,7 @@ use FML::Command::Admin::addadmin;
-# Descriptions: add a new admin user
+# Descriptions: add a new remote administrator
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to addadmin module
diff --git a/fml/lib/FML/Command/Admin/adminadd.pm b/fml/lib/FML/Command/Admin/adminadd.pm
index 6eb109e7..de44154c 100644
--- a/fml/lib/FML/Command/Admin/adminadd.pm
+++ b/fml/lib/FML/Command/Admin/adminadd.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: adminadd.pm,v 1.2 2002/09/11 23:18:06 fukachan Exp $
+# $FML: adminadd.pm,v 1.3 2002/09/22 14:56:44 fukachan Exp $
#
package FML::Command::Admin::adminadd;
@@ -17,7 +17,7 @@ use FML::Command::Admin::addadmin;
@ISA = qw(FML::Command::Admin::addadmin);
# Descriptions: add an admin user
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to subscribe module
# Return Value: none
@@ -29,7 +29,7 @@ sub process
=head1 NAME
-FML::Command::Admin::adminadd - add a new admin
+FML::Command::Admin::adminadd - add a remote administrator
=head1 SYNOPSIS
@@ -17,7 +17,7 @@ use FML::Command::Admin::addadmin;
-# Descriptions: add an admin user
+# Descriptions: add a remote administrator
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to subscribe module
diff --git a/fml/lib/FML/Command/Admin/byeadmin.pm b/fml/lib/FML/Command/Admin/byeadmin.pm
index 57c2c308..2ac71117 100644
--- a/fml/lib/FML/Command/Admin/byeadmin.pm
+++ b/fml/lib/FML/Command/Admin/byeadmin.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: byeadmin.pm,v 1.11 2003/01/27 04:36:29 fukachan Exp $
+# $FML: byeadmin.pm,v 1.12 2003/08/23 04:35:29 fukachan Exp $
#
package FML::Command::Admin::byeadmin;
@@ -16,7 +16,7 @@ use FML::Command::Admin::deladmin;
@ISA = qw(FML::Command::Admin::deladmin);
# Descriptions: remove the specified user.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to deladmin module
# Return Value: none
@@ -29,7 +29,7 @@ sub process
=head1 NAME
-FML::Command::Admin::byeadmin - remove the specified administrator
+FML::Command::Admin::byeadmin - remove the specified remote administrator
=head1 SYNOPSIS
@@ -16,7 +16,7 @@ use FML::Command::Admin::deladmin;
-# Descriptions: remove the specified user.
+# Descriptions: remove the specified remote administorator.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to deladmin module
diff --git a/fml/lib/FML/Command/Admin/byepriv.pm b/fml/lib/FML/Command/Admin/byepriv.pm
index a2841000..8f50faf2 100644
--- a/fml/lib/FML/Command/Admin/byepriv.pm
+++ b/fml/lib/FML/Command/Admin/byepriv.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: byepriv.pm,v 1.3 2002/09/11 23:18:07 fukachan Exp $
+# $FML: byepriv.pm,v 1.4 2002/09/22 14:56:44 fukachan Exp $
#
package FML::Command::Admin::byepriv;
@@ -17,7 +17,7 @@ use FML::Command::Admin::byeadmin;
@ISA = qw(FML::Command::Admin::byeadmin);
# Descriptions: remove the specified administrator
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to byeadmin module
# Return Value: none
@@ -29,7 +29,7 @@ sub process
=head1 NAME
-FML::Command::Admin::bye - remove the specified administrator
+FML::Command::Admin::bye - remove the specified remote administrator
=head1 SYNOPSIS
@@ -17,7 +17,7 @@ use FML::Command::Admin::byeadmin;
-# Descriptions: remove the specified administrator
+# Descriptions: remove the specified remote administrator
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to byeadmin module
diff --git a/fml/lib/FML/Command/Admin/deladmin.pm b/fml/lib/FML/Command/Admin/deladmin.pm
index 5d865318..414b1e71 100644
--- a/fml/lib/FML/Command/Admin/deladmin.pm
+++ b/fml/lib/FML/Command/Admin/deladmin.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: deladmin.pm,v 1.12 2003/09/27 03:00:16 fukachan Exp $
+# $FML: deladmin.pm,v 1.13 2003/11/23 03:54:45 fukachan Exp $
#
package FML::Command::Admin::deladmin;
@@ -15,7 +15,7 @@ use Carp;
=head1 NAME
-FML::Command::Admin::deladmin - remove the specified administrator
+FML::Command::Admin::deladmin - remove the specified remote administrator
=head1 SYNOPSIS
@@ -23,7 +23,7 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
-remove the specified administrator.
+remove the specified remote administrator.
=head1 METHODS
@@ -59,7 +59,7 @@ sub need_lock { 1;}
sub lock_channel { return 'command_serialize';}
# Descriptions: remove the specified administrator
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: update $member_map $recipient_map
# Return Value: none
@@ -68,13 +68,19 @@ sub process
my ($self, $curproc, $command_args) = @_;
my $config = $curproc->config();
- # target maps
+ # XXX We should always add/rewrite only $primary_*_map maps via
+ # XXX command mail, CUI and GUI.
+ # XXX Rewriting of maps not $primary_*_map is
+ # XXX 1) may be not writable.
+ # XXX 2) ambigous and dangerous
+ # XXX since the map is under controlled by other module.
+ # XXX for example, one of member_maps is under admin_member_maps.
my $member_map = $config->{ 'primary_admin_member_map' };
my $recipient_map = $config->{ 'primary_admin_recipient_map' };
my $options = $command_args->{ options };
my $address = $command_args->{ command_data } || $options->[ 0 ];
- # fundamental check
+ # fundamental sanity check
croak("address not undefined") unless defined $address;
croak("address not specified") unless $address;
croak("member_map not undefined") unless defined $member_map;
@@ -101,7 +107,7 @@ sub process
}
# Descriptions: show cgi menu to remove the administrator
# Arguments: OBJ($self)
# OBJ($curproc) HASH_REF($args) HASH_REF($command_args)
# Side Effects: update $member_map $recipient_map
@@ -59,7 +59,7 @@ sub need_lock { 1;}
sub lock_channel { return 'command_serialize';}
-# Descriptions: remove the specified administrator
+# Descriptions: remove the specified remote administrator.
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: update $member_map $recipient_map
@@ -101,7 +107,7 @@ sub process
}
-# Descriptions: show cgi menu to remove the administrator
+# Descriptions: show cgi menu to remove the remote administrator.
# Arguments: OBJ($self)
# OBJ($curproc) HASH_REF($args) HASH_REF($command_args)
diff --git a/fml/lib/FML/Command/Admin/pass.pm b/fml/lib/FML/Command/Admin/pass.pm
index db26873b..70643772 100644
--- a/fml/lib/FML/Command/Admin/pass.pm
+++ b/fml/lib/FML/Command/Admin/pass.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: pass.pm,v 1.3 2002/09/11 23:18:08 fukachan Exp $
+# $FML: pass.pm,v 1.4 2002/09/22 14:56:46 fukachan Exp $
#
package FML::Command::Admin::pass;
@@ -17,7 +17,7 @@ use FML::Command::Admin::password;
@ISA = qw(FML::Command::Admin::password);
# Descriptions: authenticate password
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to password module
# Return Value: none
@@ -30,7 +30,7 @@ sub process
=head1 NAME
-FML::Command::Admin::pass - authenticate password
+FML::Command::Admin::pass - authenticate remote admin password
=head1 SYNOPSIS
@@ -38,6 +38,7 @@ See C<FML::Command> for more details.
=head1 DESCRIPTION
+authenticate remote admin password.
an alias of C<FML::Command::Admin::password>.
=head1 CODING STYLE
@@ -17,7 +17,7 @@ use FML::Command::Admin::password;
-# Descriptions: authenticate password
+# Descriptions: authenticate remote admin password
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to password module
diff --git a/fml/lib/FML/Command/User/send.pm b/fml/lib/FML/Command/User/send.pm
index 3c6a981f..506f9dd4 100644
--- a/fml/lib/FML/Command/User/send.pm
+++ b/fml/lib/FML/Command/User/send.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: send.pm,v 1.10 2002/09/22 14:56:48 fukachan Exp $
+# $FML: send.pm,v 1.11 2002/12/18 04:22:37 fukachan Exp $
#
package FML::Command::User::send;
@@ -16,7 +16,7 @@ use FML::Command::User::get;
@ISA = qw(FML::Command::User::get);
# Descriptions: send back articles
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to get module
# Return Value: none
@@ -29,7 +29,7 @@ sub process
=head1 NAME
-FML::Command::User::send - send back artciles
+FML::Command::User::send - send back article(s)
=head1 SYNOPSIS
@@ -37,7 +37,8 @@ forwarded C<FML::Command::User::get>.
=head1 DESCRIPTION
-an alias of C<FML::Command::User::get>.
+send back article(s).
+An alias of C<FML::Command::User::get>.
=head1 CODING STYLE
@@ -16,7 +16,7 @@ use FML::Command::User::get;
-# Descriptions: send back articles
+# Descriptions: send back article(s)
# Arguments: OBJ($self) OBJ($curproc) HASH_REF($command_args)
# Side Effects: forward request to get module